
.. py:currentmodule:: pythreejs

Plane
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: Plane(normal=[0,0,0], constant=0, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/math/Plane


    .. py:attribute:: normal

        .. sourcecode:: python

            Vector3(default_value=[0,0,0]).tag(sync=True)

    .. py:attribute:: constant

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

